@@ -32,8 +32,7 @@
 #'                      Default is 5.
 #' @param honesty Whether to use honest splitting (i.e., sub-sample splitting). Default is TRUE.
 #'  For a detailed description of honesty, honesty.fraction, honesty.prune.leaves, and recommendations for
-#'  parameter tuning, see the grf
-#'  \href{https://grf-labs.github.io/grf/REFERENCE.html#honesty-honesty-fraction-honesty-prune-leaves}{algorithm reference}.
+#'  parameter tuning, see the grf algorithm reference.
 #' @param honesty.fraction The fraction of data that will be used for determining splits if honesty = TRUE. Corresponds
 #'                         to set J1 in the notation of the paper. Default is 0.5 (i.e. half of the data is used for
 #'                         determining splits).
@@ -154,7 +153,7 @@ quantile_forest <- function(X, Y,
 #'                    automatically selects an appropriate amount.
 #' @param ... Additional arguments (currently ignored).
 #'
-#' @return Predictions at each test point for each desired quantile.
+#' @return A list with elements `predictions`: a matrix with predictions at each test point for each desired quantile.
 #'
 #' @examples
 #' \donttest{
@@ -193,7 +192,7 @@ predict.quantile_forest <- function(object,
   # If possible, use pre-computed predictions.
   quantiles.orig <- object[["quantiles.orig"]]
   if (is.null(newdata) && identical(quantiles, quantiles.orig) && !is.null(object$predictions)) {
-    return(object$predictions)
+    return(list(predictions = object$predictions))
   }
 
   num.threads <- validate_num_threads(num.threads)
@@ -208,8 +207,10 @@ predict.quantile_forest <- function(object,
   if (!is.null(newdata)) {
     validate_newdata(newdata, object$X.orig, allow.na = TRUE)
     test.data <- create_test_matrices(newdata)
-    do.call.rcpp(quantile_predict, c(train.data, test.data, args))
+    ret <- do.call.rcpp(quantile_predict, c(train.data, test.data, args))
   } else {
-    do.call.rcpp(quantile_predict_oob, c(train.data, args))
+    ret <- do.call.rcpp(quantile_predict_oob, c(train.data, args))
   }
+
+  list(predictions = ret)
 }
