@@ -127,20 +127,6 @@ private:
                    const std::set<size_t>& skip,
                    size_t num_samples);
 
-  /**
-  * Draw random numbers without replacement and with weighted probabilites from vector of indices.
-  * @param result Vector to add results to. Will not be cleaned before filling.
-  * @param max Specifies the interval to draw from:  0 ... (max-1).
-  * @param num_samples Number of samples to draw
-  * @param weights A weight for each element of indices
-  */
-  void draw_weighted(std::vector<size_t>& result,
-                     size_t max,
-                     size_t num_samples,
-                     const std::vector<double>& weights);
-
-
-
     /**
    * Fisher-Yates algorithm for sampling without replacement, faster for larger num_samples
    * Idea from Knuth 1985, The Art of Computer Programming, Vol. 2, Sec. 3.4.2 Algorithm P
@@ -150,9 +136,9 @@ private:
    * @param num_samples Number of samples to draw
    */
   void draw_fisher_yates(std::vector<size_t>& result,
-                  size_t max,
-                  const std::set<size_t>& skip,
-                  size_t num_samples);
+                         size_t max,
+                         const std::set<size_t>& skip,
+                         size_t num_samples);
 
   SamplingOptions options;
   std::mt19937_64 random_number_generator;
