@@ -34,7 +34,7 @@ namespace grf {
 class ProbabilitySplittingRuleFactory final: public SplittingRuleFactory {
 public:
   ProbabilitySplittingRuleFactory(size_t num_classes);
-  std::unique_ptr<SplittingRule> create(const Data& data,
+  std::unique_ptr<SplittingRule> create(size_t max_num_unique_values,
                                         const TreeOptions& options) const;
 
 private:
